@@ -5,6 +5,7 @@ module PkgTestsOuter
 original_depot_path = copy(Base.DEPOT_PATH)
 original_load_path = copy(Base.LOAD_PATH)
 original_env = copy(ENV)
+original_project = Base.active_project()
 
 module PkgTestsInner
 
@@ -12,8 +13,15 @@ import Pkg
 
 # Because julia CI doesn't run stdlib tests via `Pkg.test` test deps must be manually installed if missing
 if Base.find_package("HistoricalStdlibVersions") === nothing
-    @info "Installing HistoricalStdlibVersions for Pkg tests"
-    Pkg.add("HistoricalStdlibVersions") # Needed for custom julia version resolve tests
+    @debug "Installing HistoricalStdlibVersions for Pkg tests"
+    iob = IOBuffer()
+    Pkg.activate(; temp = true)
+    try
+        Pkg.add("HistoricalStdlibVersions", io=iob) # Needed for custom julia version resolve tests
+    catch
+        println(String(take!(iob)))
+        rethrow()
+    end
 end
 
 import HistoricalStdlibVersions
@@ -32,7 +40,7 @@ if (server = Pkg.pkg_server()) !== nothing && Sys.which("curl") !== nothing
 end
 
 ### Disable logging output if true (default)
-hide_logs = Pkg.get_bool_env("JULIA_PKG_TEST_QUIET", default="true")
+hide_logs = Base.get_bool_env("JULIA_PKG_TEST_QUIET", true)
 
 logdir = get(ENV, "JULIA_TEST_VERBOSE_LOGS_DIR", nothing)
 ### Send all Pkg output to a file called Pkg.log
@@ -87,7 +95,12 @@ Logging.with_logger(hide_logs ? Logging.NullLogger() : Logging.current_logger())
     end
 end
 
-@showtime Base.Filesystem.temp_cleanup_purge(force=true)
+if haskey(ENV, "CI")
+    # if CI don't clean up as it will be slower than the runner filesystem reset
+    empty!(Base.Filesystem.TEMP_CLEANUP)
+else
+    @showtime Base.Filesystem.temp_cleanup_purge(force=true)
+end
 
 end # module
 
@@ -103,4 +116,6 @@ for (k, v) in pairs(original_env)
     ENV[k] = v
 end
 
+Base.set_active_project(original_project)
+
 end # module
